@@ -27,7 +27,7 @@
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <folks/folks.h>
 #include <folks/folks-telepathy.h>
@@ -130,7 +130,7 @@ individual_menu_add_personas (GtkMenuShell *menu,
 
   /* return early if these entries would add nothing beyond the "quick" items */
   if (persona_count <= 1)
-    return;
+    goto out;
 
   /* add a separator before the list of personas */
   item = gtk_separator_menu_item_new ();
@@ -266,6 +266,7 @@ while_finish:
       g_clear_object (&persona);
     }
 
+out:
   g_clear_object (&iter);
 }
 
@@ -288,7 +289,7 @@ find_phone_accounts (void)
   am = tp_account_manager_dup ();
   g_return_val_if_fail (am != NULL, NULL);
 
-  accounts = tp_account_manager_get_valid_accounts (am);
+  accounts = tp_account_manager_dup_valid_accounts (am);
   for (l = accounts; l != NULL; l = g_list_next (l))
     {
       TpAccount *account = l->data;
@@ -303,7 +304,7 @@ find_phone_accounts (void)
       found = g_list_prepend (found, g_object_ref (account));
     }
 
-  g_list_free (accounts);
+  g_list_free_full (accounts, g_object_unref);
   g_object_unref (am);
 
   return found;
