@@ -32,8 +32,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 
-#include <telepathy-glib/account-manager.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-connection-managers.h>
@@ -51,7 +50,7 @@ empathy_accounts_has_non_salut_accounts (TpAccountManager *manager)
   gboolean ret = FALSE;
   GList *accounts, *l;
 
-  accounts = tp_account_manager_get_valid_accounts (manager);
+  accounts = tp_account_manager_dup_valid_accounts (manager);
 
   for (l = accounts ; l != NULL; l = g_list_next (l))
     {
@@ -62,7 +61,7 @@ empathy_accounts_has_non_salut_accounts (TpAccountManager *manager)
         }
     }
 
-  g_list_free (accounts);
+  g_list_free_full (accounts, g_object_unref);
 
   return ret;
 }
@@ -73,9 +72,9 @@ empathy_accounts_has_accounts (TpAccountManager *manager)
   GList *accounts;
   gboolean has_accounts;
 
-  accounts = tp_account_manager_get_valid_accounts (manager);
+  accounts = tp_account_manager_dup_valid_accounts (manager);
   has_accounts = (accounts != NULL);
-  g_list_free (accounts);
+  g_list_free_full (accounts, g_object_unref);
 
   return has_accounts;
 }
