@@ -36,9 +36,7 @@
 #include <cheese-gtk.h>
 #endif
 
-#include <telepathy-glib/account-manager.h>
-#include <telepathy-glib/defs.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-connection-managers.h>
@@ -77,7 +75,7 @@ find_account (TpAccountManager *mgr,
   GList *accounts, *l;
   TpAccount *found = NULL;
 
-  accounts = tp_account_manager_get_valid_accounts (mgr);
+  accounts = tp_account_manager_dup_valid_accounts (mgr);
   for (l = accounts; l != NULL; l = g_list_next (l))
     {
       if (!tp_strdiff (tp_proxy_get_object_path (l->data), path))
@@ -87,7 +85,7 @@ find_account (TpAccountManager *mgr,
         }
     }
 
-  g_list_free (accounts);
+  g_list_free_full (accounts, g_object_unref);
   return found;
 }
 
