@@ -23,9 +23,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <telepathy-glib/account-channel-request.h>
-#include <telepathy-glib/util.h>
-#include <telepathy-glib/interfaces.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <telepathy-farstream/telepathy-farstream.h>
 
