@@ -28,8 +28,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 
-#include <telepathy-glib/account-manager.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
 #include <folks/folks.h>
 
 #include <libempathy/empathy-contact.h>
@@ -943,6 +942,16 @@ roster_window_key_press_event_cb  (GtkWidget *window,
   return FALSE;
 }
 
+static void
+unprepare_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  GtkWidget *self = user_data;
+
+  gtk_widget_destroy (self);
+}
+
 static void
 roster_window_chat_quit_cb (GSimpleAction *action,
     GVariant *parameter,
@@ -950,7 +959,14 @@ roster_window_chat_quit_cb (GSimpleAction *action,
 {
   EmpathyRosterWindow *self = user_data;
 
-  gtk_widget_destroy (GTK_WIDGET (self));
+  /* Destroying the window will make us leave the main loop and so exit the
+   * process. Before doing so we want to unprepare the individual manager.
+   * Just hide the window now and actually destroy it once Folks is done.
+   */
+  gtk_widget_hide (GTK_WIDGET (self));
+
+  empathy_individual_manager_unprepare_async (self->priv->individual_manager,
+      unprepare_cb, self);
 }
 
 static void
@@ -1507,7 +1523,7 @@ set_notebook_page (EmpathyRosterWindow *self)
 
   gtk_spinner_stop (GTK_SPINNER (self->priv->spinner_loading));
 
-  accounts = tp_account_manager_get_valid_accounts (
+  accounts = tp_account_manager_dup_valid_accounts (
       self->priv->account_manager);
 
   len = g_list_length (accounts);
@@ -1560,7 +1576,7 @@ set_notebook_page (EmpathyRosterWindow *self)
   display_page_contact_list (self);
 
 out:
-  g_list_free (accounts);
+  g_list_free_full (accounts, g_object_unref);
 }
 
 static void
@@ -1636,7 +1652,8 @@ account_manager_prepared_cb (GObject *source_object,
       return;
     }
 
-  accounts = tp_account_manager_get_valid_accounts (self->priv->account_manager);
+  accounts = tp_account_manager_dup_valid_accounts (
+      self->priv->account_manager);
   for (j = accounts; j != NULL; j = j->next)
     {
       TpAccount *account = TP_ACCOUNT (j->data);
@@ -1655,7 +1672,7 @@ account_manager_prepared_cb (GObject *source_object,
 
   set_notebook_page (self);
 
-  g_list_free (accounts);
+  g_list_free_full (accounts, g_object_unref);
 }
 
 void
@@ -2272,8 +2289,6 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
       G_CALLBACK (button_account_settings_clicked_cb), self);
   g_signal_connect (self->priv->button_online, "clicked",
       G_CALLBACK (button_online_clicked_cb), self);
-
-  set_notebook_page (self);
 }
 
 GtkWidget *
